# Cognitive Atlas Python API

[![Circle CI](https://circleci.com/gh/CognitiveAtlas/cogat-python.svg?style=svg)](https://circleci.com/gh/CognitiveAtlas/cogat-python)

This API gives python access to the RESTful API in the Cognitive Atlas (alpha).

- tasks
- concepts
- disorders
- contrasts

### Documentation

Read our complete [documentation](https://cogat-python.readthedocs.org) for getting started.


### Python 2.* notice

If you need cognitiveatlas specifically for python 2, the last released version was 0.0.18:

```bash
$ pip install cognitiveatlas==0.0.18
```
